Package iaif_utils provides a set usefull functions to process financial data, in order to prepare it for AI systems. It is used in the e-book Introduction to Artificial Intelligence in Finance (https://books.google.com.br/books/about?id=epbEEQAAQBAJ)


Pyhton Framework with  functions to process financial data (iaif_utils)
==========================================

Documentation
=============

See the e-Book Introduction to Artificial Intelligence in Finance (https://books.google.com.br/books/about?id=epbEEQAAQBAJ)

Source code
===========

https://github.com/paulo-al-castro/iaif_utils/

Contact
=======

paulo.al.castro@gmail.com